@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Linker::PE::MSVC;
-$ExtUtils::Builder::Linker::PE::MSVC::VERSION = '0.022';
+$ExtUtils::Builder::Linker::PE::MSVC::VERSION = '0.023';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use parent qw/ExtUtils::Builder::Linker::COFF/;
 
 sub _init {
 	my ($self, %args) = @_;
-	$args{ld} ||= ['link'];
+	$args{ld} //= ['link'];
 	$self->ExtUtils::Builder::Linker::COFF::_init(%args);
 	return;
 }
@@ -19,7 +19,7 @@ sub linker_flags {
 	my @ret;
 	push @ret, $self->new_argument(ranking =>  5, value => ['/nologo']);
 	push @ret, $self->new_argument(ranking => 10, value => ['/dll']) if $self->type eq 'shared-library' or $self->type eq 'loadable-object';
-	push @ret, map { $self->new_argument(ranking => $_->{ranking}, value => [ "/libpath:-L$_->{value}" ]) } @{ $self->{library_dirs} };
+	push @ret, map { $self->new_argument(ranking => $_->{ranking}, value => [ "/libpath:$_->{value}" ]) } @{ $self->{library_dirs} };
 	push @ret, map { $self->new_argument(ranking => $_->{ranking}, value => [ "$_->{value}.lib" ]) } @{ $self->{libraries} };
 	push @ret, $self->new_argument(ranking => 50, value => [ @{$from} ]);
 	push @ret, $self->new_argument(ranking => 80, value => ["/OUT:$to"]);
@@ -27,14 +27,6 @@ sub linker_flags {
 	return @ret;
 }
 
-sub post_action {
-	my ($self, $from, $to, %opts) = @_;
-	my @ret = $self->SUPER::post_action(%opts);
-	my $manifest = $opts{manifest} || "$to.manifest";
-	push @ret, ExtUtils::Builder::Action::Command->new(command => [ 'if', 'exist', $manifest, 'mt', '-nologo', '-manifest', $manifest, "-outputresource:$to;2" ]);
-	return @ret;
-}
-
 1;
 
 __END__
@@ -49,7 +41,7 @@ ExtUtils::Builder::Linker::PE::MSVC
 
 =head1 VERSION
 
-version 0.022
+version 0.023
 
 =head1 AUTHOR
 
